=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2009-06-26 06:25:57 +0000
+++ drizzled/sql_base.cc	2009-07-01 15:03:18 +0000
@@ -21,6 +21,7 @@
 #include <assert.h>
 
 #include <signal.h>
+#include <dirent.h>
 
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -35,7 +36,6 @@
 #include <mysys/my_pthread.h>
 
 #include <drizzled/sql_select.h>
-#include <mysys/my_dir.h>
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
 #include <drizzled/nested_join.h>
@@ -4995,11 +4995,11 @@
 
 bool drizzle_rm_tmp_tables(ListenHandler &listen_handler)
 {
-  uint32_t  idx;
   char	filePath[FN_REFLEN], filePathCopy[FN_REFLEN];
-  MY_DIR *dirp;
-  FILEINFO *file;
+  DIR *dirp;
   Session *session;
+  struct dirent d_entry;
+  struct dirent *d_result;
 
   assert(drizzle_tmpdir);
 
@@ -5008,51 +5008,50 @@
   session->thread_stack= (char*) &session;
   session->store_globals();
 
-  /* Remove all temp tables in the tmpdir */
-  /* See if the directory exists */
-  if ((dirp = my_dir(drizzle_tmpdir ,MYF(MY_WME | MY_DONT_SORT))))
-  {
-    /* Remove all SQLxxx tables from directory */
-    for (idx=0 ; idx < (uint32_t) dirp->number_off_files ; idx++)
+  if ((dirp= opendir(drizzle_tmpdir)) == NULL)
+  {
+    my_errno= errno;
+    my_error(ER_CANT_READ_DIR, MYF(0), drizzle_tmpdir, my_errno);
+    delete session;
+    return false;
+  }
+
+  /* Remove all SQLxxx tables from directory */
+  while (!readdir_r(dirp, &d_entry, &d_result) && (d_result != NULL))
+  {
+    if (!memcmp(d_entry.d_name, TMP_FILE_PREFIX, TMP_FILE_PREFIX_LENGTH))
     {
-      file=dirp->dir_entry+idx;
-
-      /* skiping . and .. */
-      if (file->name[0] == '.' && (!file->name[1] ||
-                                   (file->name[1] == '.' &&  !file->name[2])))
-        continue;
-
-      if (!memcmp(file->name, TMP_FILE_PREFIX, TMP_FILE_PREFIX_LENGTH))
+      char *ext= fn_ext(d_entry.d_name);
+      uint32_t ext_len= strlen(ext);
+      uint32_t filePath_len= snprintf(filePath, sizeof(filePath),
+                                      "%s%c%s", drizzle_tmpdir, FN_LIBCHAR,
+                                      d_entry.d_name);
+
+      if (ext_len && !memcmp(".dfe", ext, ext_len))
       {
-        char *ext= fn_ext(file->name);
-        uint32_t ext_len= strlen(ext);
-        uint32_t filePath_len= snprintf(filePath, sizeof(filePath),
-                                        "%s%c%s", drizzle_tmpdir, FN_LIBCHAR,
-                                        file->name);
-        if (!memcmp(".dfe", ext, ext_len))
+        TableShare share;
+        /* We should cut file extention before deleting of table */
+        memcpy(filePathCopy, filePath, filePath_len - ext_len);
+        filePathCopy[filePath_len - ext_len]= 0;
+        share.init(NULL, filePathCopy);
+        if (!open_table_def(session, &share))
         {
-          TableShare share;
-          /* We should cut file extention before deleting of table */
-          memcpy(filePathCopy, filePath, filePath_len - ext_len);
-          filePathCopy[filePath_len - ext_len]= 0;
-          share.init(NULL, filePathCopy);
-          if (!open_table_def(session, &share))
-          {
-            share.db_type()->deleteTable(session, filePathCopy);
-          }
-          share.free_table_share();
+          share.db_type()->deleteTable(session, filePathCopy);
         }
-        /*
-          File can be already deleted by tmp_table.file->delete_table().
-          So we hide error messages which happnes during deleting of these
-          files(MYF(0)).
-        */
-        my_delete(filePath, MYF(0));
+        share.free_table_share();
       }
+
+      /*
+        File can be already deleted by tmp_table.file->delete_table().
+        So we hide error messages which happnes during deleting of these
+        files(MYF(0)).
+      */
+      my_delete(filePath, MYF(0));
     }
-    my_dirend(dirp);
   }
 
+  (void) closedir(dirp);
+
   delete session;
 
   return false;

=== modified file 'mysys/default.cc'
--- mysys/default.cc	2009-06-30 18:31:32 +0000
+++ mysys/default.cc	2009-07-02 16:37:48 +0000
@@ -708,6 +708,8 @@
 
           rc= readdir_r(dirp, &dirent_entry, &dirent_result);
         }
+
+        (void) closedir(dirp);
       }
       else if ((!strncmp(ptr, include_keyword, sizeof(include_keyword) - 1)) &&
                my_isspace(&my_charset_utf8_general_ci, ptr[sizeof(include_keyword)-1]))

